summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice')
-rw-r--r--vcs/cvsservice/annotatepage.cpp4
-rw-r--r--vcs/cvsservice/annotateview.cpp4
-rw-r--r--vcs/cvsservice/annotateview.h2
-rw-r--r--vcs/cvsservice/changelog.cpp4
-rw-r--r--vcs/cvsservice/checkoutdialog.cpp2
-rw-r--r--vcs/cvsservice/checkoutdialogbase.ui10
-rw-r--r--vcs/cvsservice/commitdialogbase.ui6
-rw-r--r--vcs/cvsservice/commitdlg.cpp4
-rw-r--r--vcs/cvsservice/cvsdiffpage.cpp4
-rw-r--r--vcs/cvsservice/cvsdir.cpp14
-rw-r--r--vcs/cvsservice/cvsdir.h6
-rw-r--r--vcs/cvsservice/cvsentry.cpp2
-rw-r--r--vcs/cvsservice/cvsfileinfoprovider.cpp22
-rw-r--r--vcs/cvsservice/cvsfileinfoprovider.h2
-rw-r--r--vcs/cvsservice/cvsformbase.ui2
-rw-r--r--vcs/cvsservice/cvslogdialog.cpp2
-rw-r--r--vcs/cvsservice/cvslogpage.cpp6
-rw-r--r--vcs/cvsservice/cvsoptions.cpp8
-rw-r--r--vcs/cvsservice/cvspart.cpp32
-rw-r--r--vcs/cvsservice/cvspartimpl.cpp4
-rw-r--r--vcs/cvsservice/cvsprocesswidget.cpp4
-rw-r--r--vcs/cvsservice/cvsprocesswidget.h2
-rw-r--r--vcs/cvsservice/diffdialog.cpp2
-rw-r--r--vcs/cvsservice/diffdialogbase.ui8
-rw-r--r--vcs/cvsservice/diffwidget.cpp12
-rw-r--r--vcs/cvsservice/diffwidget.h2
-rw-r--r--vcs/cvsservice/editorsdialog.cpp4
-rw-r--r--vcs/cvsservice/editorsdialogbase.ui2
-rw-r--r--vcs/cvsservice/integrator/fetcherdlgbase.ui2
-rw-r--r--vcs/cvsservice/integrator/initdlg.ui2
-rw-r--r--vcs/cvsservice/integrator/integratordlg.cpp14
-rw-r--r--vcs/cvsservice/integrator/integratordlgbase.ui8
-rw-r--r--vcs/cvsservice/releaseinputdialogbase.ui10
-rw-r--r--vcs/cvsservice/tagdialogbase.ui6
34 files changed, 109 insertions, 109 deletions
diff --git a/vcs/cvsservice/annotatepage.cpp b/vcs/cvsservice/annotatepage.cpp
index 4c838cf9..cdcd0fdc 100644
--- a/vcs/cvsservice/annotatepage.cpp
+++ b/vcs/cvsservice/annotatepage.cpp
@@ -9,7 +9,7 @@
* *
***************************************************************************/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqregexp.h>
#include <tqstringlist.h>
#include <tqdatetime.h>
@@ -106,7 +106,7 @@ void AnnotatePage::slotJobExited( bool normalExit, int exitStatus )
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Annotate failed with exitStatus == %1").tqarg( exitStatus), i18n("Annotate Failed") );
+ KMessageBox::sorry( this, i18n("Annotate failed with exitStatus == %1").arg( exitStatus), i18n("Annotate Failed") );
return;
}
diff --git a/vcs/cvsservice/annotateview.cpp b/vcs/cvsservice/annotateview.cpp
index 597415f1..bd8014d8 100644
--- a/vcs/cvsservice/annotateview.cpp
+++ b/vcs/cvsservice/annotateview.cpp
@@ -170,7 +170,7 @@ void AnnotateView::addLine(TQString rev, TQString author, TQDateTime date,
}
-TQSize AnnotateView::tqsizeHint() const
+TQSize AnnotateView::sizeHint() const
{
TQFontMetrics fm(fontMetrics());
return TQSize(100 * fm.width("0"), 20 * fm.lineSpacing());
@@ -189,7 +189,7 @@ void AnnotateView::maybeTip( const TQPoint & p )
return;
}
- TQRect r = tqitemRect( item );
+ TQRect r = itemRect( item );
//get the dimension of the author + the date column
TQRect headerRect = header()->sectionRect(AnnotateViewItem::AuthorColumn);
headerRect = headerRect.unite(header()->sectionRect(AnnotateViewItem::DateColumn));
diff --git a/vcs/cvsservice/annotateview.h b/vcs/cvsservice/annotateview.h
index 956c0251..7586616e 100644
--- a/vcs/cvsservice/annotateview.h
+++ b/vcs/cvsservice/annotateview.h
@@ -42,7 +42,7 @@ public:
void addLine(TQString rev, TQString author, TQDateTime date, TQString content,
TQString comment, bool odd);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
void maybeTip( const TQPoint & p );
private:
diff --git a/vcs/cvsservice/changelog.cpp b/vcs/cvsservice/changelog.cpp
index 18deee0f..93aec07d 100644
--- a/vcs/cvsservice/changelog.cpp
+++ b/vcs/cvsservice/changelog.cpp
@@ -11,7 +11,7 @@
#include <tqdatetime.h>
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <kemailsettings.h>
@@ -24,7 +24,7 @@ ChangeLogEntry::ChangeLogEntry()
authorEmail = emailConfig.getSetting( KEMailSettings::EmailAddress );
authorName = emailConfig.getSetting( KEMailSettings::RealName );
- TQDate currDate = TQDate::tqcurrentDate();
+ TQDate currDate = TQDate::currentDate();
date = currDate.toString( "yyyy-MM-dd" );
}
diff --git a/vcs/cvsservice/checkoutdialog.cpp b/vcs/cvsservice/checkoutdialog.cpp
index be20d977..87c9cd15 100644
--- a/vcs/cvsservice/checkoutdialog.cpp
+++ b/vcs/cvsservice/checkoutdialog.cpp
@@ -13,7 +13,7 @@
#include <tqpushbutton.h>
#include <tqcombobox.h>
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <klistview.h>
#include <kurlrequester.h>
diff --git a/vcs/cvsservice/checkoutdialogbase.ui b/vcs/cvsservice/checkoutdialogbase.ui
index 0639364d..38f1e7f0 100644
--- a/vcs/cvsservice/checkoutdialogbase.ui
+++ b/vcs/cvsservice/checkoutdialogbase.ui
@@ -56,7 +56,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<grid>
<property name="name">
@@ -106,7 +106,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<grid>
<property name="name">
@@ -122,7 +122,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>156</width>
<height>20</height>
@@ -238,7 +238,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<hbox>
<property name="name">
@@ -254,7 +254,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>421</width>
<height>20</height>
diff --git a/vcs/cvsservice/commitdialogbase.ui b/vcs/cvsservice/commitdialogbase.ui
index eabd9c57..61805f99 100644
--- a/vcs/cvsservice/commitdialogbase.ui
+++ b/vcs/cvsservice/commitdialogbase.ui
@@ -42,7 +42,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -88,7 +88,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<hbox>
<property name="name">
@@ -104,7 +104,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>350</width>
<height>20</height>
diff --git a/vcs/cvsservice/commitdlg.cpp b/vcs/cvsservice/commitdlg.cpp
index 18850643..35dbb391 100644
--- a/vcs/cvsservice/commitdlg.cpp
+++ b/vcs/cvsservice/commitdlg.cpp
@@ -11,10 +11,10 @@
* *
***************************************************************************/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
-#include <tqtextedit.h>
+#include <textedit.h>
#include <tqpushbutton.h>
#include <kapplication.h>
diff --git a/vcs/cvsservice/cvsdiffpage.cpp b/vcs/cvsservice/cvsdiffpage.cpp
index 04a37607..fcdb8b27 100644
--- a/vcs/cvsservice/cvsdiffpage.cpp
+++ b/vcs/cvsservice/cvsdiffpage.cpp
@@ -9,8 +9,8 @@
* *
***************************************************************************/
-#include <tqtextedit.h>
-#include <tqlayout.h>
+#include <textedit.h>
+#include <layout.h>
#include <tqregexp.h>
#include <tqdir.h>
#include <tqstringlist.h>
diff --git a/vcs/cvsservice/cvsdir.cpp b/vcs/cvsservice/cvsdir.cpp
index c9e9ab51..c1d90973 100644
--- a/vcs/cvsservice/cvsdir.cpp
+++ b/vcs/cvsservice/cvsdir.cpp
@@ -10,7 +10,7 @@
***************************************************************************/
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include "cvsdir.h"
@@ -173,7 +173,7 @@ TQStringList CVSDir::registeredEntryList() const
bool CVSDir::isRegistered( const TQString fileName ) const
{
- CVSEntry entry = filetqStatus( fileName );
+ CVSEntry entry = fileStatus( fileName );
return entry.isValid() && entry.fileName() == fileName;
}
@@ -197,7 +197,7 @@ void CVSDir::refreshEntriesCache() const
///////////////////////////////////////////////////////////////////////////////
-CVSEntry CVSDir::filetqStatus( const TQString &fileName, bool refreshCache ) const
+CVSEntry CVSDir::fileStatus( const TQString &fileName, bool refreshCache ) const
{
if (refreshCache)
refreshEntriesCache();
@@ -284,7 +284,7 @@ void CVSDir::doNotIgnoreFile( const TQString &fileName )
///////////////////////////////////////////////////////////////////////////////
-VCSFileInfoMap CVSDir::dirtqStatus() const
+VCSFileInfoMap CVSDir::dirStatus() const
{
VCSFileInfoMap vcsInfo;
/// Convert to VCSFileInfoMap: \FIXME : any speed improvement here?
@@ -293,7 +293,7 @@ VCSFileInfoMap CVSDir::dirtqStatus() const
for ( ; it != end; ++it)
{
const TQString &fileName = (*it);
- const CVSEntry entry = filetqStatus( fileName );
+ const CVSEntry entry = fileStatus( fileName );
vcsInfo.insert( fileName, entry.toVCSFileInfo() );
}
@@ -303,7 +303,7 @@ VCSFileInfoMap CVSDir::dirtqStatus() const
///////////////////////////////////////////////////////////////////////////////
-VCSFileInfoMap *CVSDir::cacheableDirtqStatus() const
+VCSFileInfoMap *CVSDir::cacheableDirStatus() const
{
VCSFileInfoMap *vcsInfo = new VCSFileInfoMap;
/// Convert to VCSFileInfoMap: \FIXME : any speed improvement here?
@@ -312,7 +312,7 @@ VCSFileInfoMap *CVSDir::cacheableDirtqStatus() const
for ( ; it != end; ++it)
{
const TQString &fileName = (*it);
- const CVSEntry entry = filetqStatus( fileName );
+ const CVSEntry entry = fileStatus( fileName );
vcsInfo->insert( fileName, entry.toVCSFileInfo() );
}
diff --git a/vcs/cvsservice/cvsdir.h b/vcs/cvsservice/cvsdir.h
index dc7cb53a..1d3f7d85 100644
--- a/vcs/cvsservice/cvsdir.h
+++ b/vcs/cvsservice/cvsdir.h
@@ -46,11 +46,11 @@ public:
* @param refreshCache update internal cache re-parsing "<dirPath>/CVS/Entries"
* @return an empty CVSEntry if the file is not present
*/
- CVSEntry filetqStatus( const TQString &fileName, bool refreshCache = false ) const;
+ CVSEntry fileStatus( const TQString &fileName, bool refreshCache = false ) const;
/**
*/
- VCSFileInfoMap dirtqStatus() const;
- VCSFileInfoMap *cacheableDirtqStatus() const;
+ VCSFileInfoMap dirStatus() const;
+ VCSFileInfoMap *cacheableDirStatus() const;
/**
* @return true if the file is registered into repository, false otherwise
*/
diff --git a/vcs/cvsservice/cvsentry.cpp b/vcs/cvsservice/cvsentry.cpp
index bf478f7c..e9d7b676 100644
--- a/vcs/cvsservice/cvsentry.cpp
+++ b/vcs/cvsservice/cvsentry.cpp
@@ -10,7 +10,7 @@
***************************************************************************/
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include "cvsentry.h"
#include "cvsdir.h"
diff --git a/vcs/cvsservice/cvsfileinfoprovider.h b/vcs/cvsservice/cvsfileinfoprovider.h
index ead2d113..0a3d8887 100644
--- a/vcs/cvsservice/cvsfileinfoprovider.h
+++ b/vcs/cvsservice/cvsfileinfoprovider.h
@@ -40,7 +40,7 @@ public:
virtual const VCSFileInfoMap *status( const TQString &dirPath ) ;
// -- Async interface for requesting data
- virtual bool requesttqStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
+ virtual bool requestStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
public slots:
void updateStatusFor( const CVSDir& );
diff --git a/vcs/cvsservice/cvsformbase.ui b/vcs/cvsservice/cvsformbase.ui
index 62abbfd5..875bac49 100644
--- a/vcs/cvsservice/cvsformbase.ui
+++ b/vcs/cvsservice/cvsformbase.ui
@@ -197,7 +197,7 @@ Most of the thime you'll just reuse the project name</string>
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>51</width>
<height>20</height>
diff --git a/vcs/cvsservice/cvslogdialog.cpp b/vcs/cvsservice/cvslogdialog.cpp
index df00d8a5..6d192f38 100644
--- a/vcs/cvsservice/cvslogdialog.cpp
+++ b/vcs/cvsservice/cvslogdialog.cpp
@@ -79,7 +79,7 @@ void CVSLogDialog::slotDiffRequested( const TQString &pathName, const TQString &
kdDebug(9006) << "CVSLogDialog::slotDiffRequested()" << endl;
// Create a new CVSDiffPage and start diffing process
- TQString diffTitle = i18n("Diff between %1 and %2").tqarg( revA ).tqarg( revB );
+ TQString diffTitle = i18n("Diff between %1 and %2").arg( revA ).arg( revB );
TQVBox *vbox = addVBoxPage( diffTitle );
CVSDiffPage *diffPage = new CVSDiffPage( m_cvsService, vbox );
diffPage->startDiff( pathName, revA, revB );
diff --git a/vcs/cvsservice/cvslogpage.cpp b/vcs/cvsservice/cvslogpage.cpp
index c9659e0c..226b9689 100644
--- a/vcs/cvsservice/cvslogpage.cpp
+++ b/vcs/cvsservice/cvslogpage.cpp
@@ -9,8 +9,8 @@
* *
***************************************************************************/
-#include <tqtextbrowser.h>
-#include <tqlayout.h>
+#include <textbrowser.h>
+#include <layout.h>
#include <tqregexp.h>
#include <tqdir.h>
#include <tqstringlist.h>
@@ -113,7 +113,7 @@ void CVSLogPage::slotJobExited( bool normalExit, int exitStatus )
// m_part->core()->running( m_part, false );
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").tqarg( exitStatus), i18n("Log Failed") );
+ KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").arg( exitStatus), i18n("Log Failed") );
return;
}
diff --git a/vcs/cvsservice/cvsoptions.cpp b/vcs/cvsservice/cvsoptions.cpp
index 6f2894e6..20cc198e 100644
--- a/vcs/cvsservice/cvsoptions.cpp
+++ b/vcs/cvsservice/cvsoptions.cpp
@@ -10,7 +10,7 @@
***************************************************************************/
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <kdebug.h>
#include <kconfig.h>
@@ -24,9 +24,9 @@
// Macros
///////////////////////////////////////////////////////////////////////////////
-#define default_revert TQString::tqfromLatin1("-C")
-#define default_diff TQString::tqfromLatin1("-p")
-#define default_rsh TQString::tqfromLatin1("")
+#define default_revert TQString::fromLatin1("-C")
+#define default_diff TQString::fromLatin1("-p")
+#define default_rsh TQString::fromLatin1("")
#define default_contextLines 3
#define default_compression 0
diff --git a/vcs/cvsservice/cvspart.cpp b/vcs/cvsservice/cvspart.cpp
index bca0d2f2..9df91a9b 100644
--- a/vcs/cvsservice/cvspart.cpp
+++ b/vcs/cvsservice/cvspart.cpp
@@ -321,45 +321,45 @@ void CvsServicePart::contextMenu( TQPopupMenu *popup, const Context *context )
popup->insertSeparator();
int id = subMenu->insertItem( actionCommit->text(), this, TQT_SLOT(slotCommit()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
+ subMenu->setWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
// CvsService let to do log and diff operations only on one file (or directory) at time
if (m_urls.count() == 1)
{
id = subMenu->insertItem( actionDiff->text(), this, TQT_SLOT(slotDiff()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
+ subMenu->setWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
id = subMenu->insertItem( actionLog->text(), this, TQT_SLOT(slotLog()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
+ subMenu->setWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
id = subMenu->insertItem( actionAnnotate->text(), this, TQT_SLOT(slotAnnotate()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
+ subMenu->setWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
}
id = subMenu->insertItem( actionEditors->text(), this, TQT_SLOT(slotEditors()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
+ subMenu->setWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
id = subMenu->insertItem( actionEdit->text(), this, TQT_SLOT(slotEdit()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
+ subMenu->setWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
id = subMenu->insertItem( actionUnEdit->text(), this, TQT_SLOT(slotUnEdit()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
+ subMenu->setWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
id = subMenu->insertItem( actionAdd->text(), this, TQT_SLOT(slotAdd()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
+ subMenu->setWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
id = subMenu->insertItem( actionAddBinary->text(), this, TQT_SLOT(slotAddBinary()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
+ subMenu->setWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
id = subMenu->insertItem( actionRemove->text(), this, TQT_SLOT(slotRemove()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
+ subMenu->setWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
subMenu->insertSeparator();
id = subMenu->insertItem( actionTag->text(), this, TQT_SLOT(slotTag()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
+ subMenu->setWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
id = subMenu->insertItem( actionUnTag->text(), this, TQT_SLOT(slotUnTag()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
+ subMenu->setWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
id = subMenu->insertItem( actionUpdate->text(), this, TQT_SLOT(slotUpdate()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
+ subMenu->setWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
id = subMenu->insertItem( actionRemoveSticky->text(), this, TQT_SLOT(slotRemoveSticky()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
+ subMenu->setWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
subMenu->insertSeparator();
id = subMenu->insertItem( actionAddToIgnoreList->text(), this, TQT_SLOT(slotAddToIgnoreList()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
+ subMenu->setWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
id = subMenu->insertItem( actionRemoveFromIgnoreList->text(), this, TQT_SLOT(slotRemoveFromIgnoreList()) );
- subMenu->tqsetWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
+ subMenu->setWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
// Now insert in parent menu
popup->insertItem( i18n("CvsService"), subMenu );
diff --git a/vcs/cvsservice/cvspartimpl.cpp b/vcs/cvsservice/cvspartimpl.cpp
index b8b1685d..7556f7bc 100644
--- a/vcs/cvsservice/cvspartimpl.cpp
+++ b/vcs/cvsservice/cvspartimpl.cpp
@@ -211,7 +211,7 @@ bool CvsServicePartImpl::isRegisteredInRepository( const TQString &projectDirect
kdDebug(9006) << k_funcinfo << " Error: " << cvsdir.path() << " is not a valid CVS directory " << endl;
return false;
}
- CVSEntry entry = cvsdir.filetqStatus( url.fileName() );
+ CVSEntry entry = cvsdir.fileStatus( url.fileName() );
return entry.isValid();
}
}
@@ -639,7 +639,7 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
return;
CVSDir cvsdir = CVSDir( urlList[0].directory() );
- CVSEntry entry = cvsdir.filetqStatus( urlList[0].fileName() );
+ CVSEntry entry = cvsdir.fileStatus( urlList[0].fileName() );
DiffDialog dlg(entry);
if (dlg.exec() != TQDialog::Accepted)
diff --git a/vcs/cvsservice/cvsprocesswidget.cpp b/vcs/cvsservice/cvsprocesswidget.cpp
index ed7f3da2..b1e888ff 100644
--- a/vcs/cvsservice/cvsprocesswidget.cpp
+++ b/vcs/cvsservice/cvsprocesswidget.cpp
@@ -142,7 +142,7 @@ bool CvsProcessWidget::startJob( const DCOPRef &aJob )
// disconnect 3rd party slots from our signals
disconnect( TQT_SIGNAL(jobFinished(bool, int)) );
- showInfo( i18n("Started job: %1").tqarg( cmdLine ) );
+ showInfo( i18n("Started job: %1").arg( cmdLine ) );
#ifdef MYDCOPDEBUG
g_dcopExitCounter = 0;
@@ -187,7 +187,7 @@ void CvsProcessWidget::slotJobExited( bool normalExit, int exitStatus )
m_job = 0;
}
TQString exitMsg = i18n("Job finished with exitCode == %1");
- showInfo( exitMsg.tqarg( exitStatus) );
+ showInfo( exitMsg.arg( exitStatus) );
m_part->core()->running( m_part, false );
m_part->mainWindow()->statusBar()->message( i18n("Done CVS command ..."), 2000 );
diff --git a/vcs/cvsservice/cvsprocesswidget.h b/vcs/cvsservice/cvsprocesswidget.h
index ad2ec45a..fa302a4b 100644
--- a/vcs/cvsservice/cvsprocesswidget.h
+++ b/vcs/cvsservice/cvsprocesswidget.h
@@ -12,7 +12,7 @@
#ifndef _CVSPROCESSWIDGET_H_
#define _CVSPROCESSWIDGET_H_
-#include <tqtextedit.h>
+#include <textedit.h>
#include <tqstringlist.h>
#include "cvsservicedcopIface.h"
diff --git a/vcs/cvsservice/diffdialog.cpp b/vcs/cvsservice/diffdialog.cpp
index a141d2a8..c86ae0ce 100644
--- a/vcs/cvsservice/diffdialog.cpp
+++ b/vcs/cvsservice/diffdialog.cpp
@@ -83,7 +83,7 @@ void DiffDialog::languageChange() {
//FIXME: We need a function in CVSEntry to return the latest revision there is in cvs
// if(!m_entry.revision().isNull())
-// diffLocalHeadRadio->setText( tr2i18n( "Local copy and &HEAD (%1)" ).tqarg( m_entry.revision()) );
+// diffLocalHeadRadio->setText( tr2i18n( "Local copy and &HEAD (%1)" ).arg( m_entry.revision()) );
}
#include "diffdialog.moc"
diff --git a/vcs/cvsservice/diffdialogbase.ui b/vcs/cvsservice/diffdialogbase.ui
index b4995cb4..a5e07812 100644
--- a/vcs/cvsservice/diffdialogbase.ui
+++ b/vcs/cvsservice/diffdialogbase.ui
@@ -35,7 +35,7 @@
</property>
<widget class="TQLayoutWidget" row="2" column="0">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -69,7 +69,7 @@
</widget>
<widget class="TQLayoutWidget" row="4" column="0">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<grid>
<property name="name">
@@ -171,7 +171,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -187,7 +187,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>130</width>
<height>20</height>
diff --git a/vcs/cvsservice/diffwidget.cpp b/vcs/cvsservice/diffwidget.cpp
index b0f60a20..b1891a20 100644
--- a/vcs/cvsservice/diffwidget.cpp
+++ b/vcs/cvsservice/diffwidget.cpp
@@ -9,8 +9,8 @@
* *
***************************************************************************/
-#include <tqlayout.h>
-#include <tqtextedit.h>
+#include <layout.h>
+#include <textedit.h>
#include <tqpopupmenu.h>
#include <tqcursor.h>
#include <tqfile.h>
@@ -70,7 +70,7 @@ TQPopupMenu* KDiffTextEdit::createPopupMenu( const TQPoint& p )
int i = 0;
for ( TQStringList::Iterator it = extPartsTranslated.begin(); it != extPartsTranslated.end(); ++it ) {
- popup->insertItem( i18n( "Show in %1" ).tqarg( *it ), i + POPUP_BASE, i );
+ popup->insertItem( i18n( "Show in %1" ).arg( *it ), i + POPUP_BASE, i );
i++;
}
if ( !extPartsTranslated.isEmpty() )
@@ -186,8 +186,8 @@ DiffWidget::DiffWidget( TQWidget *parent, const char *name, WFlags f ):
// te->setMinimumSize( 300, 200 );
connect( te, TQT_SIGNAL(externalPartRequested(const TQString&)), this, TQT_SLOT(loadExtPart(const TQString&)) );
- TQVBoxLayout* tqlayout = new TQVBoxLayout( this );
- tqlayout->addWidget( te );
+ TQVBoxLayout* layout = new TQVBoxLayout( this );
+ layout->addWidget( te );
}
DiffWidget::~DiffWidget()
@@ -226,7 +226,7 @@ void DiffWidget::loadExtPart( const TQString& partName )
if ( !extPart || !extPart->widget() )
return;
- tqlayout()->add( extPart->widget() );
+ layout()->add( extPart->widget() );
setExtPartVisible( true );
diff --git a/vcs/cvsservice/diffwidget.h b/vcs/cvsservice/diffwidget.h
index c220e4f0..c4828096 100644
--- a/vcs/cvsservice/diffwidget.h
+++ b/vcs/cvsservice/diffwidget.h
@@ -13,7 +13,7 @@
#define _DIFFWIDGET_H_
#include <tqwidget.h>
-#include <tqtextedit.h>
+#include <textedit.h>
#include <tqstringlist.h>
#include <kurl.h>
diff --git a/vcs/cvsservice/editorsdialog.cpp b/vcs/cvsservice/editorsdialog.cpp
index 79695840..bbd8443f 100644
--- a/vcs/cvsservice/editorsdialog.cpp
+++ b/vcs/cvsservice/editorsdialog.cpp
@@ -15,7 +15,7 @@
#include <kdebug.h>
#include <dcopref.h>
-#include <tqtextbrowser.h>
+#include <textbrowser.h>
#include <tqregexp.h>
#include "editorsdialog.h"
@@ -61,7 +61,7 @@ void EditorsDialog::slotJobExited( bool normalExit, int exitStatus )
{
if (!normalExit)
{
- KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").tqarg( exitStatus), i18n("Log Failed") );
+ KMessageBox::sorry( this, i18n("Log failed with exitStatus == %1").arg( exitStatus), i18n("Log Failed") );
return;
}
diff --git a/vcs/cvsservice/editorsdialogbase.ui b/vcs/cvsservice/editorsdialogbase.ui
index 933d477f..37af7c1b 100644
--- a/vcs/cvsservice/editorsdialogbase.ui
+++ b/vcs/cvsservice/editorsdialogbase.ui
@@ -46,7 +46,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/vcs/cvsservice/integrator/fetcherdlgbase.ui b/vcs/cvsservice/integrator/fetcherdlgbase.ui
index 398af4cf..9028b325 100644
--- a/vcs/cvsservice/integrator/fetcherdlgbase.ui
+++ b/vcs/cvsservice/integrator/fetcherdlgbase.ui
@@ -134,7 +134,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/vcs/cvsservice/integrator/initdlg.ui b/vcs/cvsservice/integrator/initdlg.ui
index 6e5b76f1..82e26c55 100644
--- a/vcs/cvsservice/integrator/initdlg.ui
+++ b/vcs/cvsservice/integrator/initdlg.ui
@@ -53,7 +53,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/vcs/cvsservice/integrator/integratordlg.cpp b/vcs/cvsservice/integrator/integratordlg.cpp
index 961094fc..5ae31ed1 100644
--- a/vcs/cvsservice/integrator/integratordlg.cpp
+++ b/vcs/cvsservice/integrator/integratordlg.cpp
@@ -21,10 +21,10 @@
#include <tqfile.h>
#include <tqdir.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqcombobox.h>
#include <tqregexp.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqcheckbox.h>
#include <kapplication.h>
@@ -81,11 +81,11 @@ void IntegratorDlg::init_clicked()
if (!proc->normalExit())
KMessageBox::error(this, i18n("cvs init did not exit normally. Please check if cvs is installed and works correctly."), i18n("Init CVS Repository"));
else if (proc->exitStatus() != 0)
- KMessageBox::error(this, i18n("cvs init exited with status %1. Please check if the cvs location is correct.").tqarg(proc->exitStatus()), i18n("Init CVS Repository"));
+ KMessageBox::error(this, i18n("cvs init exited with status %1. Please check if the cvs location is correct.").arg(proc->exitStatus()), i18n("Init CVS Repository"));
else
{
- repository->insertItem(TQString(":local:%1").tqarg(url));
- repository->setCurrentText(TQString(":local:%1").tqarg(url));
+ repository->insertItem(TQString(":local:%1").arg(url));
+ repository->setCurrentText(TQString(":local:%1").arg(url));
}
}
}
@@ -122,13 +122,13 @@ void IntegratorDlg::accept()
proc->setWorkingDirectory(m_projectLocation);
*proc << "cvs";
*proc << "-d" << repository->currentText() << "import"
- << "-m" << TQString("\"%1\"").tqarg(comment->text()) << module->text()
+ << "-m" << TQString("\"%1\"").arg(comment->text()) << module->text()
<< vendorTag->text() << releaseTag->text();
proc->start(KProcess::Block);
if (!proc->normalExit())
KMessageBox::error(this, i18n("cvs import did not exit normally. Please check if cvs is installed and works correctly."), i18n("Init CVS Repository"));
else if (proc->exitStatus() != 0)
- KMessageBox::error(this, i18n("cvs import exited with status %1. Please check if the cvs location is correct.").tqarg(proc->exitStatus()), i18n("Init CVS Repository"));
+ KMessageBox::error(this, i18n("cvs import exited with status %1. Please check if the cvs location is correct.").arg(proc->exitStatus()), i18n("Init CVS Repository"));
else
{
kdDebug() << "Project is in: " << m_projectLocation << endl;
diff --git a/vcs/cvsservice/integrator/integratordlgbase.ui b/vcs/cvsservice/integrator/integratordlgbase.ui
index 8e7cc979..6b53c738 100644
--- a/vcs/cvsservice/integrator/integratordlgbase.ui
+++ b/vcs/cvsservice/integrator/integratordlgbase.ui
@@ -29,7 +29,7 @@
</widget>
<widget class="TQLayoutWidget" row="1" column="1">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<grid>
<property name="name">
@@ -103,7 +103,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -279,7 +279,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
diff --git a/vcs/cvsservice/releaseinputdialogbase.ui b/vcs/cvsservice/releaseinputdialogbase.ui
index dbc59f7e..e6e65b15 100644
--- a/vcs/cvsservice/releaseinputdialogbase.ui
+++ b/vcs/cvsservice/releaseinputdialogbase.ui
@@ -37,7 +37,7 @@
<property name="title">
<string>Revision</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignLeft</set>
</property>
<vbox>
@@ -57,7 +57,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -92,7 +92,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -158,7 +158,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -174,7 +174,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
diff --git a/vcs/cvsservice/tagdialogbase.ui b/vcs/cvsservice/tagdialogbase.ui
index 2ac067b3..86390490 100644
--- a/vcs/cvsservice/tagdialogbase.ui
+++ b/vcs/cvsservice/tagdialogbase.ui
@@ -24,7 +24,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -83,7 +83,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -99,7 +99,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>200</width>
<height>20</height>
diff --git a/vcs/cvsservice/cvsfileinfoprovider.cpp b/vcs/cvsservice/cvsfileinfoprovider.cpp
index 2ed764f4..cbfc726f 100644
--- a/vcs/cvsservice/cvsfileinfoprovider.cpp
+++ b/vcs/cvsservice/cvsfileinfoprovider.cpp
@@ -59,14 +59,14 @@ const VCSFileInfoMap *CVSFileInfoProvider::status( const TQString &dirPath )
delete m_cachedDirEntries;
CVSDir cvsdir( projectDirectory() + TQDir::separator() + dirPath );
m_previousDirPath = dirPath;
- m_cachedDirEntries = cvsdir.cacheableDirtqStatus();
+ m_cachedDirEntries = cvsdir.cacheableDirStatus();
}
return m_cachedDirEntries;
}
///////////////////////////////////////////////////////////////////////////////
-bool CVSFileInfoProvider::requesttqStatus( const TQString &dirPath, void *callerData, bool recursive, bool checkRepos )
+bool CVSFileInfoProvider::requestStatus( const TQString &dirPath, void *callerData, bool recursive, bool checkRepos )
{
m_savedCallerData = callerData;
if (m_requestStatusJob)
@@ -131,11 +131,11 @@ void CVSFileInfoProvider::propagateUpdate()
void CVSFileInfoProvider::updateStatusFor(const CVSDir& dir)
{
- m_cachedDirEntries = dir.cacheableDirtqStatus();
+ m_cachedDirEntries = dir.cacheableDirStatus();
printOutFileInfoMap( *m_cachedDirEntries );
/* FileTree will call requesttqStatus() everytime the user expands a directory
* Unfortunatly requesttqStatus() will be called before the
* VCSFileTreeViewItem of the directory will be filled with the files
* it contains. Meaning, m_savedCallerData contains no childs at that
* time. When a dcop call is made to run "cvs status" this is no problem.
@@ -196,7 +196,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
{
TQRegExp rx_recordStart( "^=+$" );
TQRegExp rx_fileName( "^File: (\\.|\\-|\\w)+" );
- TQRegExp rx_filetqStatus( "Status: (\\.|-|\\s|\\w)+" );
+ TQRegExp rx_fileStatus( "Status: (\\.|-|\\s|\\w)+" );
TQRegExp rx_fileWorkRev( "\\bWorking revision:" );
TQRegExp rx_fileRepoRev( "\\bRepository revision:" );
//TQRegExp rx_stickyTag( "\\s+(Sticky Tag:\\W+(w+|\\(none\\)))" );
@@ -204,7 +204,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
//TQRegExp rx_stickyOptions( "" ); //@todo
TQString fileName,
- filetqStatus,
+ fileStatus,
workingRevision,
repositoryRevision,
stickyTag,
@@ -224,12 +224,12 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
if (rx_recordStart.exactMatch( s ))
state = 1;
- else if (state == 1 && rx_fileName.search( s ) >= 0 && rx_filetqStatus.search( s ) >= 0) // FileName
+ else if (state == 1 && rx_fileName.search( s ) >= 0 && rx_fileStatus.search( s ) >= 0) // FileName
{
fileName = rx_fileName.cap().replace( "File:", "" ).stripWhiteSpace();
- filetqStatus = rx_filetqStatus.cap().replace( "Status:", "" ).stripWhiteSpace();
+ fileStatus = rx_fileStatus.cap().replace( "Status:", "" ).stripWhiteSpace();
++state; // Next state
- kdDebug(9006) << ">> " << fileName << ", " << filetqStatus << endl;
+ kdDebug(9006) << ">> " << fileName << ", " << fileStatus << endl;
}
else if (state == 2 && rx_fileWorkRev.search( s ) >= 0)
{
@@ -266,7 +266,7 @@ VCSFileInfoMap *CVSFileInfoProvider::parse( TQStringList stringStream )
{
// Package stuff, put into map and get ready for a new record
VCSFileInfo vcsInfo( fileName, workingRevision, repositoryRevision,
- String2EnumState( filetqStatus ) );
+ String2EnumState( fileStatus ) );
kdDebug(9006) << "== Inserting: " << vcsInfo.toString() << endl;
vcsStates->insert( fileName, vcsInfo );
}
@@ -131,11 +131,11 @@ void CVSFileInfoProvider::propagateUpdate()
printOutFileInfoMap( *m_cachedDirEntries );
- /* FileTree will call requesttqStatus() everytime the user expands a directory
- * Unfortunatly requesttqStatus() will be called before the
+ /* FileTree will call requestStatus() everytime the user expands a directory
+ * Unfortunatly requestStatus() will be called before the
* VCSFileTreeViewItem of the directory will be filled with the files
* it contains. Meaning, m_savedCallerData contains no childs at that